summaryrefslogtreecommitdiffstats
path: root/examples/pytde-sampler/dialogs/bugreport.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/pytde-sampler/dialogs/bugreport.py')
-rw-r--r--examples/pytde-sampler/dialogs/bugreport.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/pytde-sampler/dialogs/bugreport.py b/examples/pytde-sampler/dialogs/bugreport.py
index b06717c..74fce7e 100644
--- a/examples/pytde-sampler/dialogs/bugreport.py
+++ b/examples/pytde-sampler/dialogs/bugreport.py
@@ -1,7 +1,7 @@
iconName = 'core'
labelText = 'KBugReport'
##~ if we wanted to, we could define the name of a KDE class used for lookup of
##~ the documentation url. The 'labelText' string above already
##~ specifies what we want.
##~ docItemName = 'KBugReport'
@@ -11,7 +11,7 @@ from tdecore import i18n
from tdeui import TDEAboutDialog, KPushButton, KBugReport, KTextEdit
-helpText = ("KDE provides a way to report bugs from applications. This dialog"
+helpText = ("TDE provides a way to report bugs from applications. This dialog"
"is typically available from the application 'Help' menu.")
@@ -1,7 +1,7 @@
iconName = 'core'
labelText = 'KBugReport'
-##~ if we wanted to, we could define the name of a KDE class used for lookup of
+##~ if we wanted to, we could define the name of a TDE class used for lookup of
##~ the documentation url. The 'labelText' string above already
##~ specifies what we want.